@@ -1,10 +1,5 @@
 # region: docstring
-# --- directly after """ is required to prevent the generated README.md from staring with
-# a blank line, which invalides the  front matter that GitHub Pages (Jekyll) uses to
-# generate the README.html.
-"""---
----
-
+"""
 # OpenApiDriver for Robot Framework®
 
 OpenApiDriver is an extension of the Robot Framework® DataDriver library that allows
@@ -78,6 +73,13 @@ module also implements a number of keywords.
 Details about the Keywords can be found
 [here](https://marketsquare.github.io/robotframework-openapidriver/openapidriver.html).
 
+The OpenApiDriver also support handling of relations between resources within the scope
+of the API being validated as well as handling dependencies on resources outside the
+scope of the API. In addition there is support for handling restrictions on the values
+of parameters and properties.
+Details about the `mappings_path` variable usage can be found
+[here](https://marketsquare.github.io/robotframework-openapidriver/advanced_use.md).
+
 ---
 ## Limitations
 
@@ -86,9 +88,8 @@ data types and properties. The following list details the most important ones:
 - Only JSON request and response bodies are currently supported.
 - The unique identifier for a resource as used in the ``paths`` section of the
     openapi document is expected to be the ``id`` property on a resource of that type.
-- The ``id`` is expected to be a UUID (v4).
-- No support for query strings at this time.
-- No support for headers.
+- Limited support for query strings.
+- No support for headers at this time.
 - Limited support for authentication
     - ``username`` and ``password`` can be passed as parameters to use Basic Authentication
     - A [requests AuthBase instance](https://docs.python-requests.org/en/latest/api/#authentication)
@@ -137,22 +138,24 @@ class OpenApiDriver(DataDriver, DynamicCore):
     ROBOT_LIBRARY_VERSION = __version__
     ROBOT_LIBRARY_DOC_FORMAT = "ROBOT"
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         source: str,
-        ignored_endpoints: List[str] = [],
-        ignored_responses: List[int] = [],
-        ignored_testcases: List[List[str]] = [],
+        ignored_endpoints: Optional[List[str]] = None,
+        ignored_responses: Optional[List[int]] = None,
+        ignored_testcases: Optional[List[List[str]]] = None,
         ignore_fastapi_default_422: bool = False,
         origin: str = "",
         base_path: str = "",
         mappings_path: Union[str, Path] = "",
         username: str = "",
         password: str = "",
+        security_token: str = "",
         auth: Optional[AuthBase] = None,
         response_validation: ValidationLevel = ValidationLevel.WARN,
         disable_server_validation: bool = True,
         require_body_for_invalid_url: bool = False,
+        invalid_property_default_response: int = 422,
     ):
         # region: docstring
         """
@@ -192,6 +195,9 @@ class OpenApiDriver(DataDriver, DynamicCore):
         === password ===
         The password to be used for Basic Authentication.
 
+        === security_token ===
+        The token to be used for token based security using the `Authorization` header.
+
         === auth ===
         A [https://docs.python-requests.org/en/latest/api/#authentication | requests AuthBase instance]
         to be used for authentication instead of the ``username`` and ``password``.
@@ -219,8 +225,16 @@ class OpenApiDriver(DataDriver, DynamicCore):
         either a 404 or a 422 or 400 Response is normally returned. If the API being tested
         processes the request body before checking if the requested resource exists, set
         this parameter to True.
+
+        === invalid_property_default_response ===
+        The default response code for requests with a JSON body that does not comply with
+        the schema. Example: a value outside the specified range or a string value for a
+        property defined as integer in the schema.
         """
         # endregion
+        ignored_endpoints = ignored_endpoints if ignored_endpoints else []
+        ignored_responses = ignored_responses if ignored_responses else []
+        ignored_testcases = ignored_testcases if ignored_testcases else []
         DataDriver.__init__(
             self,
             # FIXME: Enable when DataDriver accepts AbstractReaderClass subclasses
@@ -241,10 +255,12 @@ class OpenApiDriver(DataDriver, DynamicCore):
             mappings_path=mappings_path,
             username=username,
             password=password,
+            security_token=security_token,
             auth=auth,
             response_validation=response_validation,
             disable_server_validation=disable_server_validation,
             require_body_for_invalid_url=require_body_for_invalid_url,
+            invalid_property_default_response=invalid_property_default_response,
         )
         DynamicCore.__init__(self, [openapi_executors])
 
@@ -252,7 +268,3 @@ class OpenApiDriver(DataDriver, DynamicCore):
     # accepts an AbstractReaderClass subclass as reader_class argument
     def _data_reader(self) -> AbstractReaderClass:
         return OpenApiReader(self.reader_config)
-
-
-# Support Robot Framework import mechanism
-openapidriver = OpenApiDriver  # pylint: disable=invalid-name
